function [X_test_rec, X_test_ind] = EWOk_apply(X_test, K_all, Centroids_all, kmeans_distance)
% inputs: 
%    X_test                     : database with RSSI values and Labels
%    K_all                      : number of centroid coordinates
%    Centroids_all              : centroid coordinates
%    kmeans_distance            : distance considered for k-means
% outputs:
%    X_test_rec                 : compressed samples
%    X_test_ind                 : indexes of the comressed samples
%
% Developed by L. Klus

    X_test_exp = kron(X_test(:),ones(1,K_all));         % expand matrix dimensions
    if kmeans_distance == "sqeuclidean"
        distancess = ((X_test_exp-Centroids_all').^2);  % calculate sqeuclidean distances    
    elseif kmeans_distance == "cityblock"
        distancess = abs(X_test_exp-Centroids_all');         % calculate absolute distances    
    end
    [~, minind] = min(distancess,[],2);                  % find closest centroids
    X_test_rec = Centroids_all(minind);                 % substitute values for centroid coordinates
    X_test_rec = reshape(X_test_rec,size(X_test));      % reshape back to original matrix dimensions
    X_test_ind = reshape(minind,size(X_test));
end