function [X_cluster_ind, X_cluster_coord, Centroids_new, samplecount] = EWOk_compress(X, K, initial_centorids, kmeans_distance)
% perform adaptive k_means clustering 
% inputs : 
%   rss data (X)
%   the number of clusters (K)
%   (initial_centroids) for m-means
%   distance considered by k-means function (kmeans_distance)
% outputs: 
%   indeces of the clustered data (X_cluster_ind)
%   clustered data (X_cluster_coord)
%   adapted centroids (Centroids_new)
%   number of samples per centroid (samplecount)
%
    samplecount = zeros(size(1,K));
    
    [X_cluster_all, Centroids] = kmeans(X(:),K,'Distance',kmeans_distance,...
        'Replicates', 1, 'Start', initial_centorids); % replicates == number of repetitions of clustering, final result is the one with smallest error
    
    X_cluster = zeros(size(X_cluster_all));
    [Centroids_new, ind] = sort(Centroids);
    ind_new = 1:K;
    for cluster = 1:K
        X_cluster(X_cluster_all == ind(cluster)) = ind_new(cluster);
    end
    
    for j = 1:K
        samplecount(j) = sum(X_cluster==j); % number of samples in each cluster
    end
 
    X_cluster_coord = Centroids_new(X_cluster);    % substitute values for centroid coordinates
    X_cluster_coord = reshape(X_cluster_coord,size(X));
    X_cluster_ind = reshape(X_cluster,size(X));
end
