function [initial_centroids] = get_initial_centroids(X,K,method)
% perform initial centroid selection based on the distribution
% inputs : rss data (X), the number of clusters (K), method - either 'min',
% 'max', 'xtr', 'imin', 'imax', 'ixtr'

if nargin == 2
    method = "min";
end

if method == "min"
    initial_centroids = zeros(K,1);
    X_ = X(:);
    initial_centroids(K) = min(X_);
    X_ = X_(X_ ~= min(X_));

    x_ = sort(X_);
    f = (1:length(x_))./length(x_);

    for line = 1:K-1
       [~, index] = min(abs(f-(line/K)));
       initial_centroids(line) = x_(index);
    end
elseif method == "max"
    initial_centroids = zeros(K,1);
    X_ = X(:);
    initial_centroids(K) = max(X_);
    X_ = X_(X_ ~= min(X_));

    x_ = sort(X_);
    f = (1:length(x_))./length(x_);

    for line = 1:K-1
       [~, index] = min(abs(f-(line/K)));
       initial_centroids(line) = x_(index);
    end    
elseif method == "xtr"
    initial_centroids = zeros(K,1);
    X_ = X(:);
    initial_centroids(1) = min(X_);
    initial_centroids(K) = max(X_);
    X_ = X_(X_ ~= min(X_));

    x_ = sort(X_);
    f = (1:length(x_))./length(x_);

    for line = 1:K-2
       [~, index] = min(abs(f-(line/(K-1))));
       initial_centroids(line+1) = x_(index);
    end    
    
elseif method == "ixtr"
    initial_centroids = zeros(K,1);
    X_ = X(:);
    initial_centroids(K) = min(X_);
    initial_centroids(1) = max(X_);
    X_ = X_(X_ ~= min(X_));

    x_ = sort(X_);
    f = (1:length(x_))./length(x_);
    
    Nbins = 0;
    Mem = 0;
    for i = 1:K-1
        Nbins = Nbins+i;
    end
    
    for line = 1:K-2
       Mem = Mem+line;
       [~, index] = min(abs(f - (Nbins - Mem)/Nbins));
       initial_centroids(line+1) = x_(index);
    end    

elseif method == "imin"
    initial_centroids = zeros(K,1);
    X_ = X(:);
    initial_centroids(K) = min(X_);
    X_ = X_(X_ ~= min(X_));

    x_ = sort(X_);
    f = (1:length(x_))./length(x_);
    
    Nbins = 0;
    Mem = 0;
    for i = 1:K
        Nbins = Nbins+i;
    end
    
    for line = 1:K-1
       Mem = Mem+line;
       [~, index] = min(abs(f - (Nbins - Mem)/Nbins));
       initial_centroids(line) = x_(index);
    end    

elseif method == "imax"
    initial_centroids = zeros(K,1);
    X_ = X(:);
    initial_centroids(K) = max(X_);
    X_ = X_(X_ ~= min(X_));

    x_ = sort(X_);
    f = (1:length(x_))./length(x_);
    
    Nbins = 0;
    Mem = 0;
    for i = 1:K
        Nbins = Nbins+i;
    end
    
    for line = 1:K-1
       Mem = Mem+line;
       [~, index] = min(abs(f - (Nbins - Mem)/Nbins));
       initial_centroids(line) = x_(index);
    end 

end
end
